-- Handles the creation of the GUI for HealComm 

local currentZone = select(8,GetInstanceInfo())
local version = GetBuildInfo()
local vernum = tonumber(version:sub(1,1))
local addversion = GetAddOnMetadata("HealComm", "Version")
local addnum = tonumber(addversion:sub(1,1))
if vernum > addnum then
	vernum = addnum
end
local eras = {"Classic Era", "The Burning Crusade"}
local eraOverride = 0
local raidName1 = {"Molten Core", "Blackwing Lair", "Zul'Gurub","Ruins of Ahn'Qiraj", "Ahn'Qiraj Temple", "Naxxramas"}
local raidNum1 = {409,469,309,509,531,533}
local raidName2 = {"Karazhan", "Gruul's Lair", "Magtheridon's Lair", "Serpentshrine Cavern", "Tempest Keep (The Eye)", "Battle for Mount Hyjal", "Black Temple", "Zul'Aman", "Sunwell Plateau"}
local raidNum2 = {532,565,544,548,550,534,564,568,580}
local currentEra = eras[vernum], currentRaid, currentBoss
local raidZone = {}
for i=1, #raidName1 do 
	if raidNum1[i]==currentZone then
		raidZone.text = raidName1[i]
		eraOverride = 1
	end
end
for i=1, #raidName2 do 
	if raidNum2[i]==currentZone then
		raidZone.text = raidName2[i]
	end
end
local bosses = {}
bosses["Molten Core"] = {"Trash", "Lucifron", "Magmadar", "Gehenas", "Garr", "Baron Geddon", "Shazzrah", "Golemagg", "Sulfuron Harbinger", "Majordomo Executus", "Ragnaros"}
bosses["Blackwing Lair"] = {"Trash", "Razorgore the Untamed", "Vaelstrasz", "Broodlord Lashlayer", "Firemaw", "Ebonroc", "Flamegor", "Chrommagus", "Nefarian"}
bosses["Zul'Gurub"] = {"Trash", "High Priestess Jeklik", "High Priest Venoxis", "High Priestess Mar'li", "Bloodlord Mandokir", "Edge of Madness", "High Priest Thekal", "High Priestess Arlokk", "Jin'do the Hexxer", "Hakkar", "Gahz'ranka"}
bosses["Ruins of Ahn'Qiraj"] = {"Trash", "Kurinnaxx", "General Rajaxx", "Moam", "Buru the Gorger", "Ayamiss the Hunter", "Ossirian the Unscarred"}
bosses["Ahn'Qiraj Temple"] = {"Trash", "The Prophet Skeram", "Bug Trio", "Batleguard Sartura", "Fankriss the Unyielding", "Viscidus", "Princess Huhuran", "Twin Emperors", "Ouro", "C'thun"}
bosses["Naxxramas"] = {"Trash","Anub'Rekhan","Grand Widow Faerlina","Maexxna","Noth the Plaguebringer","Heigan the Unclean","Loatheb","Instructor Razuvious","Gothik the Harvester","The Four Horsemen","Patchwerk","Grobbulus","Gluth","Thaddius","Sapphiron","Kel'Thuzad"}
bosses["Karazhan"] = {"Trash", "Attumen the Huntsman", "Moroes", "Maiden of Virtue", "Opera House", "The Curator", "Terestian Illhoof", "Shade of Aran", "Netherspike", "Chess Event", "Prince Malchezaar", "Nightbane", "Servant Quarters"}
bosses["Gruul's Lair"] = {"Trash", "High King Maulgar", "Gruul the Dragonkiller"}
bosses["Magtheridon's Lair"] = {"Magtheridon"}
bosses["Serpentshrine Cavern"] = {"Trash", "Hydross the Unstable", "The Lurker Below", "Leotheras the Blind", "Fathom-Lord Karathress", "Morogrim Tidewalker", "Lady Vashj"}
bosses["Tempest Keep (The Eye)"] = {"Trash", "Al'ar", "Void Reaver", "High Astromancer Solarian", "Kael'thas Sunstrider"}
bosses["Battle for Mount Hyjal"] = {"Trash", "Rage Winterchill", "Anetheron", "Kaz'rogal", "Azgalor", "Archimonde"}
bosses["Black Temple"] = {"Trash", "High Warlord Naj'entus", "Supremus", "Shade of Akama", "Teron Gorefiend", "Gurtogg Bloodboil", "Reliquary of Souls", "Mother Shahraz", "Illidari Council", "Illidan Stormrage"}
bosses["Zul'Aman"] = {"Trash", "Nalorakk", "Akil'zon", "Jan'alai", "Halazzi", "Hex Lord Malacrass", "Zul'jin"}
bosses["Sunwell Plateau"] = {"Trash", "Kalecgos", "Brutallus", "Felmyst", "Eredar Twins", "M'uru", "Kik'jaeden"}
local function createLabel(frame, text)
	local label = frame:CreateFontString(nil,"BACKGROUND", "GameFontNormalSmall")
	label:SetText(text)
	label:SetWidth(100)
	label:SetHeight(25)
	label:SetTextColor(1,1,0)
	label:SetFont("Fonts\\FRIZQT__.TTF", 10)
	label:SetShadowColor(0,0,0)
	label:SetShadowOffset(1,-1)
	return label
end

local function createEditbox(parent, width, height, tabPressColumn, tabIndex, anchorWidget, xOffset, yOffset)
	local editbox = CreateFrame("EditBox", nil, parent, "InputBoxTemplate")
	editbox:SetWidth(width)
	editbox:SetHeight(height)
	editbox:SetPoint("BOTTOM",anchorWidget,"BOTTOM",xOffset,yOffset)
	editbox:SetAutoFocus(false)
	editbox:SetScript("OnTabPressed", 
		function() 
			if IsShiftKeyDown() and tabPressColumn[tabIndex-1] then
				tabPressColumn[tabIndex-1]:SetFocus()
			elseif tabPressColumn[tabIndex+1] then 
				tabPressColumn[tabIndex+1]:SetFocus()
			end
		end)
	editbox:SetScript("OnEscapePressed", function() HealComm.frame:Hide() end )
	return editbox
end

local function createButton(parent, width, height, text)
	local button = CreateFrame("Button", nil, parent, "UIPanelButtonTemplate")
	button:SetWidth(width)
	button:SetHeight(height)
	button:SetText(text)
	return button
end

function ordinal_numbers(n)
  local ordinal, digit = {"st", "nd", "rd"}, string.sub(n, -1)
  if tonumber(digit) > 0 and tonumber(digit) <= 3 and string.sub(n,-2) ~= 11 and string.sub(n,-2) ~= 12 and string.sub(n,-2) ~= 13 then
    return n .. ordinal[tonumber(digit)]
  else
    return n .. "th"
  end
end

function HealComm:CreateFrame()
	local f = CreateFrame("Frame", "HealCommConfigFrame", UIParent, BackdropTemplateMixin and "BackdropTemplate")
	f:SetFrameStrata("HIGH")
	f:SetWidth(850) 
	f:SetHeight(750)
	f:SetMovable(true)
	f:RegisterForDrag("LeftButton")
	f:EnableMouse(true)
	f:SetScript("OnDragStart", function(self) self:StartMoving() end)
	f:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
	f:SetPoint("CENTER", UIParent)
    f:SetClampedToScreen(true)
    f:SetBackdrop({
    	bgFile="Interface\\DialogFrame\\UI-DialogBox-Background", 
      	edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
      	tile=1, tileSize=16, edgeSize=16, 
      	insets={left=5, right=5, top=5, bottom=5}
	})
	
	-- make the frame referencable by the HC table 
	HealComm.frame = f

	-- insert into UISpecialFrames so that escape key will close the frame 
	tinsert(UISpecialFrames,"HealCommConfigFrame") 

	local title = f:CreateFontString(nil, "BACKGROUND", "GameFontNormalLarge")
	title:SetText("HealComm (v"..addversion..")")
	title:SetWidth(250)
	title:SetHeight(35)
	title:SetPoint("TOPRIGHT",f,"TOPRIGHT", 10, -5)
	title:SetTextColor(1,1,1)
	title:SetFont("Fonts\\FRIZQT__.TTF", 18)
	title:SetShadowColor(0,0,0)
	title:SetShadowOffset(1,-1)

	-- DROPDOWNS
	-- Era name dropdown 
	HealComm.frame.eraDropdown = CreateFrame("Frame", nil, f, "UIDropDownMenuTemplate")
	UIDropDownMenu_SetWidth(HealComm.frame.eraDropdown, 125)
	HealComm.frame.eraDropdown:SetPoint("TOP", f, "TOP", -245, -60)
	UIDropDownMenu_Initialize(HealComm.frame.eraDropdown, HealComm.EraDropdownOnload)
	if eraOverride==1 then
		UIDropDownMenu_SetSelectedValue(HealComm.frame.eraDropdown, eras[1])
		currentEra = "Classic Era"
	else
		UIDropDownMenu_SetSelectedValue(HealComm.frame.eraDropdown, eras[vernum])
	end

	-- Raid name dropdown 
	HealComm.frame.raidDropdown = CreateFrame("Frame", nil, f, "UIDropDownMenuTemplate")
	UIDropDownMenu_SetWidth(HealComm.frame.raidDropdown, 150)
	HealComm.frame.raidDropdown:SetPoint("TOP", f, "TOP", -85, -60)
	UIDropDownMenu_Initialize(HealComm.frame.raidDropdown, HealComm.RaidDropdownOnload)
	if raidZone.text then 
		UIDropDownMenu_SetSelectedValue(HealComm.frame.raidDropdown, raidZone.text)
		currentRaid = raidZone.text
	end

	-- Boss name dropdown 
	HealComm.frame.bossDropdown = CreateFrame("Frame", nil, f, "UIDropDownMenuTemplate")
	UIDropDownMenu_SetWidth(HealComm.frame.bossDropdown, 175)
	HealComm.frame.bossDropdown:SetPoint("TOP", f, "TOP", 100, -60)
	UIDropDownMenu_Initialize(HealComm.frame.bossDropdown, HealComm.BossDropdownOnload)

	-- DROPDOWN LABELS 
	-- Era name label 
	local eraNameLabel = f:CreateFontString(nil,"BACKGROUND", "GameFontNormalSmall")
	eraNameLabel:SetText("WoW Era")
	eraNameLabel:SetWidth(250)
	eraNameLabel:SetHeight(35)
	eraNameLabel:SetPoint("CENTER",HealComm.frame.eraDropdown,"TOP", 0, 10)

	-- Raid name label 
	local raidNameLabel = f:CreateFontString(nil,"BACKGROUND", "GameFontNormalSmall")
	raidNameLabel:SetText("Raid Name")
	raidNameLabel:SetWidth(250)
	raidNameLabel:SetHeight(35)
	raidNameLabel:SetPoint("CENTER",HealComm.frame.raidDropdown,"TOP", 0, 10)

	-- Boss name label 
	local bossNameLabel = f:CreateFontString(nil,"BACKGROUND", "GameFontNormalSmall")
	bossNameLabel:SetText("Boss Name")
	bossNameLabel:SetWidth(250)
	bossNameLabel:SetHeight(35)
	bossNameLabel:SetPoint("CENTER",HealComm.frame.bossDropdown,"TOP", 0, 10)

	-- HEALER LABEL 
	local healerNameLabel = createLabel(f, "Healer Name")
	healerNameLabel:SetPoint("TOPLEFT",f,"TOPLEFT", 75, -115)

	-- HEALER NAMES AND CLASS ICONS
	HealComm.frame.healerNames = {}
	HealComm.frame.healerIcons = {}
	for i=1, 15 do
		local healerEditbox = createEditbox(f, 150, 25, HealComm.frame.healerNames, i, healerNameLabel, 0, -i*25)
		healerEditbox:SetScript("OnTextChanged", function(self) HealComm:HealerNameChanged(i) end)
		HealComm.frame.healerNames[i] = healerEditbox

		local icon = CreateFrame("Frame", nil, f)
		icon:SetWidth(24)
		icon:SetHeight(24)
		icon:SetPoint("RIGHT",healerEditbox,"LEFT",-5,0)
		icon:SetMovable(true)
		icon:RegisterForDrag("LeftButton")
		icon:EnableMouse(true)
		icon:SetScript("OnDragStart", function(self) HealComm:IconDragStart(self) end)
		icon:SetScript("OnDragStop", function(self) HealComm:IconDragStop(self, i) end)
		icon.texture = icon:CreateTexture()
		HealComm.frame.healerIcons[i] = icon
		icon:Hide()
	end


	HealComm.frame.assignments = {}
	--HealComm.frame.phaseNames = {}
	for i=1, 3 do 
		-- PHASE LABELS
		local phaseLabel = createLabel(f, "Phase "..i.." /")
		phaseLabel:SetPoint("LEFT",healerNameLabel,"RIGHT",-70+i*145,15)
	
		-- ASSINGMENT LABELS
		local assignmentLabel = createLabel(f, ordinal_numbers(i).." Assignment")
		assignmentLabel:SetPoint("LEFT",healerNameLabel,"RIGHT",-70+i*145,0)


		HealComm.frame.assignments["phase"..i] = {}
		-- ASSIGNMENT EDITBOXES 
		for j=1, 15 do
			local assignmentEditbox = createEditbox(f, 120, 25, HealComm.frame.assignments["phase"..i], j, assignmentLabel, 0, -j*25)
			HealComm.frame.assignments["phase"..i][j] = assignmentEditbox
		end
	end 

	HealComm.frame.notes = {}
	local noteLabel = createLabel(f, "Broadcast Notes")
		noteLabel:SetPoint("TOPLEFT",f,"TOPLEFT", 50, -530)
	local noteEditbox = createEditbox(f, 600, 25, HealComm.frame.noteText, 1, noteLabel, 250, -20)
		noteEditbox:SetText("Everyone else: Raidheal")
		HealComm.frame.notes = noteEditbox

	
	-- PRE-SET ASSIGNMENTS GROUP
	-- heading label  
	local presetAssignmentHeadingLabel = createLabel(f, "Preset Assignments")
	presetAssignmentHeadingLabel:SetWidth(150)
	presetAssignmentHeadingLabel:SetPoint("LEFT",healerNameLabel,"RIGHT",485,0)
	HealComm.frame.presetAssignmentHeadingLabel = presetAssignmentHeadingLabel

	-- dynamic labels: name resolved %MT1-5 (if assigned) (so roster update?)
	-- draggable labels 
	HealComm.frame.presetAssignments = {}
	local staticLabels = {"Raid", "Melee", "Ranged", "Dispel/Decurse", "%MT1", "%MT2", "%MT3", "%MT4", "%MT5"}
	for k, v in pairs (staticLabels) do 
		HealComm:CreatePresetAssignment(v, k)
	end 

	-- BUTTONS
	-- Current Instance button
	local ciButton = createButton(f, 90, 50, "Set Current\nInstance")
	ciButton:SetPoint("LEFT", HealComm.frame.eraDropdown, "LEFT", -80, 2)
	ciButton:SetScript("OnClick", function(self) HealComm:ResetDropdowns() end)
	
	-- Close button 
	local closeButton = createButton(f, 100, 25, "Close")
	closeButton:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", -10, 15)
	closeButton:SetScript("OnClick", function(self) self:GetParent():Hide() end)

	-- Broadcast button
	local broadcastButton = createButton(f, 100, 25, "Broadcast")
	broadcastButton:SetPoint("RIGHT", closeButton, "LEFT", -10, 0)
	broadcastButton:SetScript("OnClick", function(self) HealComm:Broadcast() end)

	-- Save button
	local saveButton = createButton(f, 75, 25, "Save")
	saveButton:SetPoint("LEFT", HealComm.frame.bossDropdown, "RIGHT", 5, 2)
	saveButton:SetScript("OnClick", function(self) HealComm:SaveAssignments() end)
	
	-- Clear button
	local clearButton = createButton(f, 75, 25, "Clear")
	clearButton:SetPoint("LEFT", saveButton, "RIGHT", 5, 0)
	clearButton:SetScript("OnClick", function(self) HealComm:ClearAssignments() end)
	
	-- Auto fill button
	local autofillButton = createButton(f, 100, 25, "Auto Fill")
	autofillButton:SetPoint("TOP", HealComm.frame.healerNames[15], "BOTTOM", -25, -80)
	autofillButton:SetScript("OnClick", function(self) HealComm:AutoFillHealers() end)

	-- CHANNEL SETTINGS 
	-- Broadcast to Raid checkbox 
	local broadcastToRaidCheckbox = CreateFrame("CheckButton", "HealComm_broadcastToRaidCheckbox",f, "UICheckButtonTemplate")
	broadcastToRaidCheckbox:SetPoint("BOTTOM", f, "BOTTOM", -50, 140)
	broadcastToRaidCheckbox:SetHeight(25)
	broadcastToRaidCheckbox:SetWidth(25)
	-- have to use this weird method because Blizzard doesn't let you SetText on the checkbox itself
	HealComm_broadcastToRaidCheckboxText:SetText("Broadcast to Raid")
	broadcastToRaidCheckbox:SetScript("OnClick", function() HealComm:SaveReportingSettings() end)
	broadcastToRaidCheckbox.tooltip = "Broadcast assignments to raid channel"
	HealComm.frame.broadcastToRaidCheckbox = broadcastToRaidCheckbox

	-- Whisper assignments checkbox 
	local whisperAssignmentsCheckbox = CreateFrame("CheckButton", "HealComm_whisperAssignmentsCheckbox",f, "UICheckButtonTemplate")
	whisperAssignmentsCheckbox:SetPoint("BOTTOM", f, "BOTTOM", -50, 120)
	whisperAssignmentsCheckbox:SetHeight(25)
	whisperAssignmentsCheckbox:SetWidth(25)
	-- have to use this weird method because Blizzard doesn't let you SetText on the checkbox itself
	HealComm_whisperAssignmentsCheckboxText:SetText("Whisper Assignments")
	whisperAssignmentsCheckbox:SetScript("OnClick", function() HealComm:SaveReportingSettings() end)
	whisperAssignmentsCheckbox.tooltip = "Broadcast assignments to raid channel"
	HealComm.frame.whisperAssignmentsCheckbox = whisperAssignmentsCheckbox

	-- Broadcast to custom channel checkbox 
	local broadcastToCustomChannelCheckbox = CreateFrame("CheckButton", "HealComm_broadcastToCustomChannelCheckbox",f, "UICheckButtonTemplate")
	broadcastToCustomChannelCheckbox:SetPoint("BOTTOM", f, "BOTTOM", -50, 100)
	broadcastToCustomChannelCheckbox:SetHeight(25)
	broadcastToCustomChannelCheckbox:SetWidth(25)
	-- have to use this weird method because Blizzard doesn't let you SetText on the checkbox itself
	HealComm_broadcastToCustomChannelCheckboxText:SetText("Broadcast to Custom Channel")
	broadcastToCustomChannelCheckbox:SetScript("OnClick", function() HealComm:SaveReportingSettings() end)
	broadcastToCustomChannelCheckbox.tooltip = "Broadcast assignments to a custom channel"
	HealComm.frame.broadcastToCustomChannelCheckbox = broadcastToCustomChannelCheckbox

	-- Custom channel name editbox 
	local customChannelEditbox = CreateFrame("EditBox", nil, f, "InputBoxTemplate")
	customChannelEditbox:SetWidth(110)
	customChannelEditbox:SetHeight(25)
	customChannelEditbox:SetPoint("TOPLEFT",broadcastToCustomChannelCheckbox,"TOPLEFT",175,0)
	customChannelEditbox:SetAutoFocus(false)
	customChannelEditbox:SetScript("OnEscapePressed", function() HealComm.frame:Hide() end )
	customChannelEditbox:SetScript("OnTextChanged", function() HealComm:SaveReportingSettings() end)
	HealComm.frame.customChannelName = customChannelEditbox

	-- Exception List editbox 
	local exceptionLabel = createLabel(f, "Names to be ignored by Autofill (space-separated)")
	exceptionLabel:SetPoint("TOPLEFT",f,"TOPLEFT", 35, -650)
	exceptionLabel:SetWidth(300)
	local exceptionEditbox = CreateFrame("EditBox", nil, f, "InputBoxTemplate")
	exceptionEditbox:SetWidth(525)
	exceptionEditbox:SetHeight(25)
	exceptionEditbox:SetPoint("TOPLEFT",broadcastToCustomChannelCheckbox,"BOTTOM",-250,-20)
	exceptionEditbox:SetAutoFocus(false)
	exceptionEditbox:SetScript("OnEscapePressed", function() HealComm.frame:Hide() end )
	exceptionEditbox:SetScript("OnTextChanged", function() HealComm:SaveReportingSettings() end)
	HealComm.frame.exceptionList = exceptionEditbox
	-- Apply Exceptions button
	local saveExceptionButton = createButton(f, 75, 25, "Apply")
	saveExceptionButton:SetPoint("TOPRIGHT", exceptionEditbox, "TOPLEFT", -3, 0)
	saveExceptionButton:SetScript("OnClick", function(self) HealComm:UpdateRoster() end)
end

function HealComm:EraDropdownOnload(self)
	local info = {}
	for i=1, vernum do 
		info.text = eras[i]
		info.value = eras[i]
		info.func = function() 
			UIDropDownMenu_SetText(HealComm.frame.eraDropdown, eras[i]) 
			currentEra = eras[i] 
			UIDropDownMenu_ClearAll(HealComm.frame.raidDropdown)
			UIDropDownMenu_ClearAll(HealComm.frame.bossDropdown)			
		end 
		UIDropDownMenu_AddButton(info)
	end 
end

-- todo: Find more efficient way to determine Era 
function HealComm:RaidDropdownOnload(self)
	local info = {}
	if currentEra == "Classic Era" then
		for i=1, #raidName1 do 
			info.text = raidName1[i]
			info.value = raidName1[i]
			info.func = function() 
				UIDropDownMenu_SetText(HealComm.frame.raidDropdown, raidName1[i]) 
				currentRaid = raidName1[i] 
				UIDropDownMenu_ClearAll(HealComm.frame.bossDropdown)
			end 
			UIDropDownMenu_AddButton(info)
		end
	end 
	if currentEra == "The Burning Crusade" then 
		for i=1, #raidName2 do 
			info.text = raidName2[i]
			info.value = raidName2[i]
			info.func = function() 
				UIDropDownMenu_SetText(HealComm.frame.raidDropdown, raidName2[i]) 
				currentRaid = raidName2[i] 
				UIDropDownMenu_ClearAll(HealComm.frame.bossDropdown)
			end 
			UIDropDownMenu_AddButton(info)
		end
	end 
end

function HealComm:BossDropdownOnload(self)
	local info = {}
	if not currentRaid then 
		return;
	end
	for i=1, #bosses[currentRaid] do 
		info.text = bosses[currentRaid][i]
		info.value = bosses[currentRaid][i]
		info.func = function() 
			UIDropDownMenu_SetText(HealComm.frame.bossDropdown, bosses[currentRaid][i]) 
			currentBoss = bosses[currentRaid][i]
			HealComm:LoadAssignments()
		end 
		UIDropDownMenu_AddButton(info)
	end 
end

function HealComm:GetCurrentlySelectedRaidAndBoss()
	if currentRaid and currentBoss then 
		return currentRaid.." - "..currentBoss
	else 
		return nil
	end
end

function HealComm:CreatePresetAssignment(text, assignmentIndex)
	local presetAssignment = CreateFrame("Frame", nil, HealComm.frame, BackdropTemplateMixin and "BackdropTemplate")
	presetAssignment:SetWidth(120)
	presetAssignment:SetHeight(25)
    presetAssignment:SetBackdrop( { 
        bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
        edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
        tile = true, tileSize = 16, edgeSize = 16, 
        insets = { left = 4, right = 4, top = 3, bottom = 3 }
    })
    presetAssignment:SetBackdropColor(0, 0, 0, 0.9)
    presetAssignment:SetPoint("TOP", HealComm.frame.presetAssignmentHeadingLabel, "TOP", 0, -25*assignmentIndex)
    presetAssignment.text = createLabel(presetAssignment, text)
    presetAssignment.text:SetPoint("CENTER", presetAssignment, "CENTER")
    presetAssignment.text:SetTextColor(1,1,1)
	presetAssignment:SetMovable(true)
	presetAssignment:RegisterForDrag("LeftButton")
	presetAssignment:EnableMouse(true)
	presetAssignment:SetScript("OnDragStart", function(self) self:StartMoving() end)
	presetAssignment:SetScript("OnDragStop", function(self) HealComm:PresetAssignmentDragStop(self, assignmentIndex) end)
	HealComm.frame.presetAssignments[assignmentIndex] = presetAssignment

end

function HealComm:ResetDropdowns()
	--todo:  Find a way to do this without repeating a whole lot of code.
	currentZone = select(8,GetInstanceInfo())
	eraOverride = 0
	raidZone.txt = nil
	currentEra = eras[vernum]
	currentRaid = nil
	currentBoss = nil
	UIDropDownMenu_ClearAll(HealComm.frame.raidDropdown)
	UIDropDownMenu_ClearAll(HealComm.frame.bossDropdown)
	raidZone = {}
	for i=1, #raidName1 do 
		if raidNum1[i]==currentZone then
			raidZone.text = raidName1[i]
			eraOverride = 1
		end
	end
	for i=1, #raidName2 do 
		if raidNum2[i]==currentZone then
			raidZone.text = raidName2[i]
		end
	end
	UIDropDownMenu_Initialize(HealComm.frame.eraDropdown, HealComm.EraDropdownOnload)
	if eraOverride==1 then
		UIDropDownMenu_SetSelectedValue(HealComm.frame.eraDropdown, eras[1])
		currentEra = "Classic Era"
	else
		UIDropDownMenu_SetSelectedValue(HealComm.frame.eraDropdown, eras[vernum])
	end
	UIDropDownMenu_Initialize(HealComm.frame.raidDropdown, HealComm.RaidDropdownOnload)
	if raidZone.text then 
		UIDropDownMenu_SetSelectedValue(HealComm.frame.raidDropdown, raidZone.text)
		currentRaid = raidZone.text
	end
	UIDropDownMenu_Initialize(HealComm.frame.bossDropdown, HealComm.BossDropdownOnload)
	  	
end
